@@ -1,7 +1,17 @@
 import csv
 from io import StringIO
+from t2wml.wikification.utility_functions import get_provider
+
+provider = get_provider()
 
 def try_get_label(input):
+    if input[0] in ["P", "Q"]:
+        try:
+            entry = provider.get_entity(input)
+            if entry and 'label' in entry:
+                return entry['label']
+        except:
+            pass
     return input
 
 
